@@ -6,7 +6,8 @@ from evalml.problem_types import ProblemTypes
 class MulticlassClassificationObjective(ObjectiveBase):
     """Base class for all multiclass classification objectives.
 
-    problem_type (ProblemTypes): Type of problem this objective is. Set to ProblemTypes.MULTICLASS.
+    problem_types (list(ProblemType)): List of problem types that this objective is defined for.
+        Set to [ProblemTypes.MULTICLASS].
     """
 
-    problem_type = ProblemTypes.MULTICLASS
+    problem_types = [ProblemTypes.MULTICLASS]
