@@ -22,9 +22,11 @@ from .estimators import (
 from .transformers import (
     Transformer,
     OneHotEncoder,
+    TargetEncoder,
     RFClassifierSelectFromModel,
     RFRegressorSelectFromModel,
     PerColumnImputer,
+    DelayedFeatureTransformer,
     SimpleImputer,
     Imputer,
     StandardScaler,
@@ -35,4 +37,9 @@ from .transformers import (
     SelectColumns,
     TextFeaturizer,
     LSA,
+    PCA
+)
+from .ensemble import (
+    StackedEnsembleClassifier,
+    StackedEnsembleRegressor
 )
