@@ -1,4 +1,3 @@
-# flake8:noqa
 from .elasticnet_regressor import ElasticNetRegressor
 from .linear_regressor import LinearRegressor
 from .rf_regressor import RandomForestRegressor
@@ -6,3 +5,4 @@ from .catboost_regressor import CatBoostRegressor
 from .xgboost_regressor import XGBoostRegressor
 from .et_regressor import ExtraTreesRegressor
 from .baseline_regressor import BaselineRegressor
+from .decision_tree_regressor import DecisionTreeRegressor
