@@ -14,7 +14,7 @@ class ElasticNetRegressor(Estimator):
         "l1_ratio": Real(0, 1),
     }
     model_family = ModelFamily.LINEAR_MODEL
-    supported_problem_types = [ProblemTypes.REGRESSION]
+    supported_problem_types = [ProblemTypes.REGRESSION, ProblemTypes.TIME_SERIES_REGRESSION]
 
     def __init__(self, alpha=0.5, l1_ratio=0.5, max_iter=1000, normalize=False, random_state=0, **kwargs):
         parameters = {'alpha': alpha,
