@@ -14,7 +14,7 @@ class RandomForestRegressor(Estimator):
         "max_depth": Integer(1, 32),
     }
     model_family = ModelFamily.RANDOM_FOREST
-    supported_problem_types = [ProblemTypes.REGRESSION]
+    supported_problem_types = [ProblemTypes.REGRESSION, ProblemTypes.TIME_SERIES_REGRESSION]
 
     def __init__(self, n_estimators=100, max_depth=6, n_jobs=-1, random_state=0, **kwargs):
         parameters = {"n_estimators": n_estimators,
