@@ -1,7 +1,9 @@
-import pandas as pd
-
 from evalml.pipelines.components.transformers import Transformer
-from evalml.utils.gen_utils import datetime_dtypes
+from evalml.utils.gen_utils import (
+    _convert_to_woodwork_structure,
+    _convert_woodwork_types_wrapper,
+    datetime_dtypes
+)
 
 
 def _extract_year(col):
@@ -51,8 +53,8 @@ class DateTimeFeaturizer(Transformer):
                          random_state=random_state)
 
     def fit(self, X, y=None):
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
+        X = _convert_to_woodwork_structure(X)
+        X = _convert_woodwork_types_wrapper(X.to_dataframe())
         self._date_time_col_names = X.select_dtypes(include=datetime_dtypes).columns
         return self
 
@@ -66,10 +68,9 @@ class DateTimeFeaturizer(Transformer):
         Returns:
             pd.DataFrame: Transformed X
         """
-
+        X = _convert_to_woodwork_structure(X)
+        X = _convert_woodwork_types_wrapper(X.to_dataframe())
         X_t = X
-        if not isinstance(X_t, pd.DataFrame):
-            X_t = pd.DataFrame(X_t)
         features_to_extract = self.parameters["features_to_extract"]
         if len(features_to_extract) == 0:
             return X_t
