@@ -20,6 +20,7 @@ from evalml.exceptions import (
 )
 from evalml.pipelines.pipeline_base_meta import PipelineBaseMeta
 from evalml.utils import (
+    _convert_to_woodwork_structure,
     check_random_state_equality,
     classproperty,
     get_logger,
@@ -71,6 +72,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
         self._validate_estimator_problem_type()
         self._is_fitted = False
+        self._pipeline_params = parameters.get("pipeline", {})
 
     @classproperty
     def name(cls):
@@ -175,7 +177,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
             logger.info(component_string)
             component.describe(print_name=False)
 
-    def compute_estimator_features(self, X):
+    def compute_estimator_features(self, X, y=None):
         """Transforms the data by applying all pre-processing components.
 
         Arguments:
@@ -186,27 +188,28 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """
         X_t = X
         for component in self.component_graph[:-1]:
-            X_t = component.transform(X_t)
+            X_t = component.transform(X_t, y=y)
+        return X_t
+
+    def _compute_features_during_fit(self, X, y):
+        X_t = X
+        for component in self.component_graph[:-1]:
+            self.input_feature_names.update({component.name: list(X_t.columns)})
+            X_t = component.fit_transform(X_t, y=y)
+        self.input_feature_names.update({self.estimator.name: list(X_t.columns)})
         return X_t
 
     def _fit(self, X, y):
-        X_t = X
-        y_t = y
-        for component in self.component_graph[:-1]:
-            self.input_feature_names.update({component.name: list(pd.DataFrame(X_t))})
-            X_t = component.fit_transform(X_t, y_t)
-
-        self.input_feature_names.update({self.estimator.name: list(pd.DataFrame(X_t))})
-        self.estimator.fit(X_t, y_t)
+        X_t = self._compute_features_during_fit(X, y)
+        self.estimator.fit(X_t, y)
 
     @abstractmethod
     def fit(self, X, y):
         """Build a model
 
         Arguments:
-            X (pd.DataFrame or np.array): The input training data of shape [n_samples, n_features]
-
-            y (pd.Series): The target training data of length [n_samples]
+            X (ww.DataTable, pd.DataFrame or np.ndarray): The input training data of shape [n_samples, n_features]
+            y (ww.DataColumn, pd.Series, np.ndarray): The target training data of length [n_samples]
 
         Returns:
             self
@@ -217,16 +220,14 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """Make predictions using selected features.
 
         Arguments:
-            X (pd.DataFrame or np.array): Data of shape [n_samples, n_features]
+            X (ww.DataTable, pd.DataFrame, or np.ndarray): Data of shape [n_samples, n_features]
             objective (Object or string): The objective to use to make predictions
 
         Returns:
             pd.Series: Predicted values.
         """
-        if not isinstance(X, pd.DataFrame):
-            X = pd.DataFrame(X)
-
-        X_t = self.compute_estimator_features(X)
+        X = _convert_to_woodwork_structure(X)
+        X_t = self.compute_estimator_features(X, y=None)
         return self.estimator.predict(X_t)
 
     @abstractmethod
@@ -234,8 +235,8 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         """Evaluate model performance on current and additional objectives
 
         Arguments:
-            X (pd.DataFrame or np.array): Data of shape [n_samples, n_features]
-            y (pd.Series): Target data of length [n_samples]
+            X (ww.DataTable, pd.DataFrame or np.ndarray): Data of shape [n_samples, n_features]
+            y (pd.Series, ww.DataColumn, or np.ndarray): True labels of length [n_samples]
             objectives (list): Non-empty list of objectives to score on
 
         Returns:
@@ -262,7 +263,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         exceptions = OrderedDict()
         for objective in objectives:
             try:
-                if self.problem_type != objective.problem_type:
+                if not objective.is_defined_for_problem_type(self.problem_type):
                     raise ValueError(f'Invalid objective {objective.name} specified for problem type {self.problem_type}')
                 score = self._score(X, y, y_pred_proba if objective.score_needs_proba else y_pred, objective)
                 scored_successfully.update({objective.name: score})
@@ -301,7 +302,10 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
         Returns:
             dict: Dictionary of all component parameters
         """
-        return {c.name: copy.copy(c.parameters) for c in self.component_graph if c.parameters}
+        component_parameters = {c.name: copy.copy(c.parameters) for c in self.component_graph if c.parameters}
+        if self._pipeline_params:
+            component_parameters['pipeline'] = self._pipeline_params
+        return component_parameters
 
     @classproperty
     def default_parameters(cls):
@@ -319,7 +323,7 @@ class PipelineBase(ABC, metaclass=PipelineBaseMeta):
 
     @property
     def feature_importance(self):
-        """Return importance associated with each feature. Features dropped by feature selection are excluded.
+        """Return importance associated with each feature. Features dropped by the feature selection are excluded.
 
         Returns:
             pd.DataFrame including feature names and their corresponding importance
