@@ -41,7 +41,7 @@ def split_data(X, y, regression=False, test_size=.2, random_state=None):
     """Splits data into train and test sets.
 
     Arguments:
-        X (pd.DataFrame or np.array): Data of shape [n_samples, n_features]
+        X (pd.DataFrame or np.ndarray): Data of shape [n_samples, n_features]
         y (pd.Series): Target data of length [n_samples]
         regression (bool): If true, do not use stratified split
         test_size (float): Percent of train set to holdout for testing
@@ -58,7 +58,7 @@ def split_data(X, y, regression=False, test_size=.2, random_state=None):
     if regression:
         CV_method = ShuffleSplit(n_splits=1,
                                  test_size=test_size,
-                                 random_state=0)
+                                 random_state=random_state)
     else:
         CV_method = StratifiedShuffleSplit(
             n_splits=1,
@@ -73,11 +73,10 @@ def split_data(X, y, regression=False, test_size=.2, random_state=None):
 
 
 def number_of_features(dtypes):
-    """Get the number of features for specific dtypes.
+    """Get the number of features of each specific dtype in a DataFrame.
 
     Arguments:
-
-        dtypes (pd.Series): dtypes to get the number of features for
+        dtypes (pd.Series): DataFrame.dtypes to get the number of features for
 
     Returns:
         pd.Series: dtypes and the number of features for each input type
