@@ -12,17 +12,20 @@ from skopt.space import Categorical
 
 from evalml.exceptions import (
     ComponentNotYetFittedError,
+    EnsembleMissingPipelinesError,
     MethodPropertyNotFoundError
 )
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components import (
     LSA,
+    PCA,
     BaselineClassifier,
     BaselineRegressor,
     CatBoostClassifier,
     CatBoostRegressor,
     ComponentBase,
     DateTimeFeaturizer,
+    DelayedFeatureTransformer,
     DropColumns,
     DropNullColumns,
     ElasticNetClassifier,
@@ -48,12 +51,18 @@ from evalml.pipelines.components import (
     XGBoostClassifier,
     XGBoostRegressor
 )
+from evalml.pipelines.components.ensemble import (
+    StackedEnsembleClassifier,
+    StackedEnsembleRegressor
+)
 from evalml.pipelines.components.utils import (
     _all_estimators,
     _all_estimators_used_in_search,
     _all_transformers,
-    all_components
+    all_components,
+    generate_component_code
 )
+from evalml.pipelines.utils import make_pipeline_from_components
 from evalml.problem_types import ProblemTypes
 
 
@@ -136,7 +145,9 @@ def test_describe_component():
     datetime = DateTimeFeaturizer()
     text_featurizer = TextFeaturizer()
     lsa = LSA()
+    pca = PCA()
     assert enc.describe(return_dict=True) == {'name': 'One Hot Encoder', 'parameters': {'top_n': 10,
+                                                                                        'features_to_encode': None,
                                                                                         'categories': None,
                                                                                         'drop': None,
                                                                                         'handle_unknown': 'ignore',
@@ -155,6 +166,7 @@ def test_describe_component():
     assert datetime.describe(return_dict=True) == {'name': 'DateTime Featurization Component', 'parameters': {'features_to_extract': ['year', 'month', 'day_of_week', 'hour']}}
     assert text_featurizer.describe(return_dict=True) == {'name': 'Text Featurization Component', 'parameters': {'text_columns': None}}
     assert lsa.describe(return_dict=True) == {'name': 'LSA Transformer', 'parameters': {'text_columns': None}}
+    assert pca.describe(return_dict=True) == {'name': 'PCA Transformer', 'parameters': {'n_components': None, 'variance': 0.95}}
 
     # testing estimators
     base_classifier = BaselineClassifier()
@@ -193,7 +205,8 @@ def test_describe_component():
         pass
     try:
         lg_classifier = LightGBMClassifier()
-        assert lg_classifier.describe(return_dict=True) == {'name': 'LightGBM Classifier', 'parameters': {'boosting_type': 'gbdt', 'learning_rate': 0.1, 'n_estimators': 100, 'max_depth': 0, 'num_leaves': 31, 'min_child_samples': 20, 'n_jobs': -1}}
+        assert lg_classifier.describe(return_dict=True) == {'name': 'LightGBM Classifier', 'parameters': {'boosting_type': 'gbdt', 'learning_rate': 0.1, 'n_estimators': 100, 'max_depth': 0, 'num_leaves': 31,
+                                                                                                          'min_child_samples': 20, 'n_jobs': -1, 'bagging_fraction': 0.9, 'bagging_freq': 0}}
     except ImportError:
         pass
 
@@ -390,10 +403,17 @@ def test_component_parameters_getter(test_classes):
     assert component.parameters == {'test': 'parameter'}
 
 
-def test_component_parameters_init():
+def test_component_parameters_init(logistic_regression_binary_pipeline_class,
+                                   linear_regression_pipeline_class):
     for component_class in all_components():
         print('Testing component {}'.format(component_class.name))
-        component = component_class()
+        try:
+            component = component_class()
+        except EnsembleMissingPipelinesError:
+            if component_class == StackedEnsembleClassifier:
+                component = component_class(input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})])
+            elif component_class == StackedEnsembleRegressor:
+                component = component_class(input_pipelines=[linear_regression_pipeline_class(parameters={})])
         parameters = component.parameters
 
         component2 = component_class(**parameters)
@@ -443,7 +463,10 @@ def test_clone_fitted(X_y_binary):
 
 def test_components_init_kwargs():
     for component_class in all_components():
-        component = component_class()
+        try:
+            component = component_class()
+        except EnsembleMissingPipelinesError:
+            continue
         if component._component_obj is None:
             continue
 
@@ -504,6 +527,14 @@ def test_transformer_transform_output_type(X_y_binary):
             if isinstance(component, SelectColumns):
                 assert transform_output.shape == (X.shape[0], 0)
                 assert isinstance(transform_output.columns, pd.Index)
+            elif isinstance(component, PCA):
+                assert transform_output.shape[0] == X.shape[0]
+                assert transform_output.shape[1] <= X.shape[1]
+                assert isinstance(transform_output.columns, pd.Index)
+            elif isinstance(component, DelayedFeatureTransformer):
+                # We just want to check that DelayedFeaturesTransformer outputs a DataFrame
+                # The dataframe shape and index are checked in test_delayed_features_transformer.py
+                continue
             else:
                 assert transform_output.shape == X.shape
                 assert (transform_output.columns == X_cols_expected).all()
@@ -514,6 +545,10 @@ def test_transformer_transform_output_type(X_y_binary):
             if isinstance(component, SelectColumns):
                 assert transform_output.shape == (X.shape[0], 0)
                 assert isinstance(transform_output.columns, pd.Index)
+            elif isinstance(component, PCA):
+                assert transform_output.shape[0] == X.shape[0]
+                assert transform_output.shape[1] <= X.shape[1]
+                assert isinstance(transform_output.columns, pd.Index)
             else:
                 assert transform_output.shape == X.shape
                 assert (transform_output.columns == X_cols_expected).all()
@@ -560,13 +595,12 @@ def test_estimator_predict_output_type(X_y_binary):
             assert (predict_proba_output.columns == y_cols_expected).all()
 
 
-@pytest.mark.parametrize("cls", all_components())
+@pytest.mark.parametrize("cls", [cls for cls in all_components() if cls not in [StackedEnsembleRegressor, StackedEnsembleClassifier]])
 def test_default_parameters(cls):
-
     assert cls.default_parameters == cls().parameters, f"{cls.__name__}'s default parameters don't match __init__."
 
 
-@pytest.mark.parametrize("cls", all_components())
+@pytest.mark.parametrize("cls", [cls for cls in all_components() if cls not in [StackedEnsembleRegressor, StackedEnsembleClassifier]])
 def test_default_parameters_raise_no_warnings(cls):
     with warnings.catch_warnings(record=True) as w:
         warnings.simplefilter("always")
@@ -719,7 +753,7 @@ def test_transformer_check_for_fit_with_overrides(X_y_binary):
 
 def test_all_transformers_needs_fitting():
     for component_class in _all_transformers() + _all_estimators():
-        if component_class.__name__ in ['DropColumns', 'SelectColumns']:
+        if component_class.__name__ in ['DropColumns', 'SelectColumns', 'DelayedFeatureTransformer']:
             assert not component_class.needs_fitting
         else:
             assert component_class.needs_fitting
@@ -745,7 +779,8 @@ def test_all_transformers_check_fit(X_y_binary):
 
 def test_all_estimators_check_fit(X_y_binary, test_estimator_needs_fitting_false):
     X, y = X_y_binary
-    for component_class in _all_estimators() + [test_estimator_needs_fitting_false]:
+    estimators_to_check = [estimator for estimator in _all_estimators() if estimator not in [StackedEnsembleClassifier, StackedEnsembleRegressor]] + [test_estimator_needs_fitting_false]
+    for component_class in estimators_to_check:
         if not component_class.needs_fitting:
             continue
 
@@ -777,17 +812,21 @@ def test_no_fitting_required_components(X_y_binary, test_estimator_needs_fitting
             if issubclass(component_class, Estimator):
                 component.predict(X)
             else:
-                component.transform(X)
+                component.transform(X, y)
 
 
 def test_serialization(X_y_binary, tmpdir):
     X, y = X_y_binary
     path = os.path.join(str(tmpdir), 'component.pkl')
-
     for component_class in all_components():
         print('Testing serialization of component {}'.format(component_class.name))
-
-        component = component_class()
+        try:
+            component = component_class()
+        except EnsembleMissingPipelinesError:
+            if (component_class == StackedEnsembleClassifier):
+                component = component_class(input_pipelines=[make_pipeline_from_components([RandomForestClassifier()], ProblemTypes.BINARY)])
+            elif (component_class == StackedEnsembleRegressor):
+                component = component_class(input_pipelines=[make_pipeline_from_components([RandomForestRegressor()], ProblemTypes.REGRESSION)])
         component.fit(X, y)
 
         for pickle_protocol in range(cloudpickle.DEFAULT_PROTOCOL + 1):
@@ -795,7 +834,7 @@ def test_serialization(X_y_binary, tmpdir):
             loaded_component = ComponentBase.load(path)
             assert component.parameters == loaded_component.parameters
             assert component.describe(return_dict=True) == loaded_component.describe(return_dict=True)
-            if issubclass(component_class, Estimator):
+            if (issubclass(component_class, Estimator) and not (isinstance(component, StackedEnsembleClassifier) or isinstance(component, StackedEnsembleRegressor))):
                 assert (component.feature_importance == loaded_component.feature_importance).all()
 
 
@@ -816,11 +855,22 @@ def test_serialization_protocol(mock_cloudpickle_dump, tmpdir):
 
 
 @pytest.mark.parametrize("estimator_class", _all_estimators())
-def test_estimators_accept_all_kwargs(estimator_class):
-    estimator = estimator_class()
+def test_estimators_accept_all_kwargs(estimator_class,
+                                      logistic_regression_binary_pipeline_class,
+                                      linear_regression_pipeline_class):
+    try:
+        estimator = estimator_class()
+    except EnsembleMissingPipelinesError:
+        if estimator_class == StackedEnsembleClassifier:
+            estimator = estimator_class(input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})])
+        elif estimator_class == StackedEnsembleRegressor:
+            estimator = estimator_class(input_pipelines=[linear_regression_pipeline_class(parameters={})])
     if estimator._component_obj is None:
         pytest.skip(f"Skipping {estimator_class} because does not have component object.")
-    params = estimator._component_obj.get_params()
+    if estimator_class.model_family == ModelFamily.ENSEMBLE:
+        params = estimator.parameters
+    else:
+        params = estimator._component_obj.get_params()
     if estimator_class.model_family == ModelFamily.CATBOOST:
         # Deleting because we call it random_state in our api
         del params["random_seed"]
@@ -887,13 +937,33 @@ def test_component_equality():
 
 
 @pytest.mark.parametrize("component_class", all_components())
-def test_component_equality_all_components(component_class):
-    component = component_class()
+def test_component_equality_all_components(component_class,
+                                           logistic_regression_binary_pipeline_class,
+                                           linear_regression_pipeline_class):
+    if component_class.model_family == ModelFamily.ENSEMBLE and component_class.supported_problem_types == [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
+        component = component_class(input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})])
+    elif component_class.model_family == ModelFamily.ENSEMBLE and ProblemTypes.REGRESSION in component_class.supported_problem_types:
+        component = component_class(input_pipelines=[linear_regression_pipeline_class(parameters={})])
+    else:
+        component = component_class()
     parameters = component.parameters
     equal_component = component_class(**parameters)
     assert component == equal_component
 
 
+def test_component_equality_with_subclasses(test_classes):
+    MockComponent, MockEstimator, MockTransformer = test_classes
+    mock_component = MockComponent()
+    mock_estimator = MockEstimator()
+    mock_transformer = MockTransformer()
+    assert mock_component != mock_estimator
+    assert mock_component != mock_transformer
+    assert mock_estimator != mock_component
+    assert mock_estimator != mock_transformer
+    assert mock_transformer != mock_component
+    assert mock_transformer != mock_estimator
+
+
 def test_mock_component_str(test_classes):
     MockComponent, MockEstimator, MockTransformer = test_classes
 
@@ -917,8 +987,14 @@ def test_mock_component_repr():
 
 
 @pytest.mark.parametrize("component_class", all_components())
-def test_component_str(component_class):
-    component = component_class()
+def test_component_str(component_class, logistic_regression_binary_pipeline_class, linear_regression_pipeline_class):
+    try:
+        component = component_class()
+    except EnsembleMissingPipelinesError:
+        if component_class == StackedEnsembleClassifier:
+            component = component_class(input_pipelines=[logistic_regression_binary_pipeline_class(parameters={})])
+        elif component_class == StackedEnsembleRegressor:
+            component = component_class(input_pipelines=[linear_regression_pipeline_class(parameters={})])
     assert str(component) == component.name
 
 
@@ -953,3 +1029,50 @@ def test_categorical_hyperparameters(X_y_binary, categorical):
 
     assert MockComponent(agg_type="mean").fit(X, y)
     assert MockComponent(agg_type="moat", category="blue").fit(X, y)
+
+
+def test_generate_code_errors():
+    with pytest.raises(ValueError, match="Element must be a component instance"):
+        generate_component_code(make_pipeline_from_components([RandomForestClassifier()], ProblemTypes.BINARY))
+
+    with pytest.raises(ValueError, match="Element must be a component instance"):
+        generate_component_code(LinearRegressor)
+
+    with pytest.raises(ValueError, match="Element must be a component instance"):
+        generate_component_code(Imputer)
+
+    with pytest.raises(ValueError, match="Element must be a component instance"):
+        generate_component_code(ComponentBase)
+
+
+def test_generate_code():
+    expected_code = "from evalml.pipelines.components.estimators.classifiers.logistic_regression import LogisticRegressionClassifier" \
+                    "\n\nlogisticRegressionClassifier = LogisticRegressionClassifier(**{'penalty': 'l2', 'C': 1.0, 'n_jobs': -1, 'multi_class': 'auto', 'solver': 'lbfgs'})"
+    component_code = generate_component_code(LogisticRegressionClassifier())
+    assert component_code == expected_code
+
+    expected_code = "from evalml.pipelines.components.estimators.regressors.et_regressor import ExtraTreesRegressor" \
+                    "\n\nextraTreesRegressor = ExtraTreesRegressor(**{'n_estimators': 50, 'max_features': 'auto', 'max_depth': 6, 'min_samples_split': 2, 'min_weight_fraction_leaf': 0.0, 'n_jobs': -1})"
+    component_code = generate_component_code(ExtraTreesRegressor(n_estimators=50))
+    assert component_code == expected_code
+
+    expected_code = "from evalml.pipelines.components.transformers.imputers.imputer import Imputer" \
+                    "\n\nimputer = Imputer(**{'categorical_impute_strategy': 'most_frequent', 'numeric_impute_strategy': 'mean', 'categorical_fill_value': None, 'numeric_fill_value': None})"
+    component_code = generate_component_code(Imputer())
+    assert component_code == expected_code
+
+
+def test_generate_code_custom(test_classes):
+    MockComponent, MockEstimator, MockTransformer = test_classes
+
+    expected_code = "mockComponent = MockComponent(**{})"
+    component_code = generate_component_code(MockComponent())
+    assert component_code == expected_code
+
+    expected_code = "mockEstimator = MockEstimator(**{})"
+    component_code = generate_component_code(MockEstimator())
+    assert component_code == expected_code
+
+    expected_code = "mockTransformer = MockTransformer(**{})"
+    component_code = generate_component_code(MockTransformer())
+    assert component_code == expected_code
