@@ -2,6 +2,7 @@ from unittest.mock import patch
 
 import numpy as np
 import pandas as pd
+import pytest
 from pandas.testing import assert_frame_equal, assert_series_equal
 from pytest import importorskip
 
@@ -21,20 +22,6 @@ def test_problem_types():
     assert set(LightGBMClassifier.supported_problem_types) == {ProblemTypes.MULTICLASS, ProblemTypes.BINARY}
 
 
-def test_et_parameters():
-    clf = LightGBMClassifier(boosting_type="dart", learning_rate=0.5, n_estimators=20, max_depth=2, num_leaves=10, min_child_samples=10)
-    expected_parameters = {
-        "boosting_type": "dart",
-        "learning_rate": 0.5,
-        "n_estimators": 20,
-        "max_depth": 2,
-        "num_leaves": 10,
-        "min_child_samples": 10,
-        "n_jobs": -1
-    }
-    assert clf.parameters == expected_parameters
-
-
 def test_lightgbm_classifier_random_state_bounds_seed(X_y_binary):
     """ensure lightgbm's RNG doesn't fail for the min/max bounds we support on user-inputted random seeds"""
     X, y = X_y_binary
@@ -295,3 +282,24 @@ def test_binary_label_encoding(mock_fit, mock_predict, X_y_binary):
     assert_series_equal(y_arg, y_numeric)
 
     clf.predict(X)
+
+
+def test_binary_rf(X_y_binary):
+    X, y = X_y_binary
+
+    with pytest.raises(lgbm.basic.LightGBMError, match="bagging_fraction"):
+        clf = LightGBMClassifier(boosting_type="rf", bagging_freq=1, bagging_fraction=1.01)
+        clf.fit(X, y)
+
+    clf = LightGBMClassifier(boosting_type="rf", bagging_freq=0)
+    clf.fit(X, y)
+    assert clf.parameters['bagging_freq'] == 0
+    assert clf.parameters['bagging_fraction'] == 0.9
+
+
+def test_binary_goss(X_y_binary):
+    X, y = X_y_binary
+    clf = LightGBMClassifier(boosting_type="goss")
+    clf.fit(X, y)
+    assert clf.parameters['bagging_freq'] == 0
+    assert clf.parameters['bagging_fraction'] == 0.9
