@@ -9,6 +9,7 @@ from sklearn.preprocessing import label_binarize
 from skopt.space import Real
 
 from evalml.demos import load_breast_cancer
+from evalml.exceptions import NullsInColumnWarning
 from evalml.model_family import ModelFamily
 from evalml.model_understanding.graphs import (
     binary_objective_vs_threshold,
@@ -19,6 +20,7 @@ from evalml.model_understanding.graphs import (
     graph_partial_dependence,
     graph_permutation_importance,
     graph_precision_recall_curve,
+    graph_prediction_vs_actual,
     graph_roc_curve,
     normalize_confusion_matrix,
     partial_dependence,
@@ -815,6 +817,18 @@ def test_partial_dependence_not_fitted(X_y_binary, logistic_regression_binary_pi
         partial_dependence(pipeline, X, feature=0, grid_resolution=20)
 
 
+def test_partial_dependence_warning(logistic_regression_binary_pipeline_class):
+    X = pd.DataFrame({'a': [2, None, 2, 2], 'b': [1, 2, 2, 1]})
+    y = pd.Series([0, 1, 0, 1])
+    pipeline = logistic_regression_binary_pipeline_class(parameters={})
+    pipeline.fit(X, y)
+    with pytest.warns(NullsInColumnWarning, match="There are null values in the features, which will cause NaN values in the partial dependence output"):
+        partial_dependence(pipeline, X, feature=0, grid_resolution=20)
+
+    with pytest.warns(NullsInColumnWarning, match="There are null values in the features, which will cause NaN values in the partial dependence output"):
+        partial_dependence(pipeline, X, feature='a', grid_resolution=20)
+
+
 def test_graph_partial_dependence(test_pipeline):
     X, y = load_breast_cancer()
 
@@ -834,7 +848,7 @@ def test_graph_partial_dependence(test_pipeline):
 
 @patch('evalml.model_understanding.graphs.jupyter_check')
 @patch('evalml.model_understanding.graphs.import_or_raise')
-def test_jupyter_graph_check(import_check, jupyter_check, X_y_binary, test_pipeline):
+def test_jupyter_graph_check(import_check, jupyter_check, X_y_binary, X_y_regression, test_pipeline):
     pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
     X, y = X_y_binary
     clf = test_pipeline
@@ -877,3 +891,66 @@ def test_jupyter_graph_check(import_check, jupyter_check, X_y_binary, test_pipel
         graph_roc_curve(y, y_pred_proba)
         assert len(graph_valid) == 0
         import_check.assert_called_with('ipywidgets', warning=True)
+
+    Xr, yr = X_y_regression
+    with pytest.warns(None) as graph_valid:
+        rs = np.random.RandomState(42)
+        y_preds = yr * rs.random(yr.shape)
+        graph_prediction_vs_actual(yr, y_preds)
+        assert len(graph_valid) == 0
+        import_check.assert_called_with('ipywidgets', warning=True)
+
+
+def test_graph_prediction_vs_actual_default():
+    go = pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
+    y_true = [1, 2, 3000, 4, 5, 6, 7, 8, 9, 10, 11, 12]
+    y_pred = [5, 4, 2, 8, 6, 6, 5, 1, 7, 2, 1, 3000]
+
+    fig = graph_prediction_vs_actual(y_true, y_pred)
+    assert isinstance(fig, type(go.Figure()))
+    fig_dict = fig.to_dict()
+    assert fig_dict['layout']['title']['text'] == 'Predicted vs Actual Values Scatter Plot'
+    assert fig_dict['layout']['xaxis']['title']['text'] == 'Prediction'
+    assert fig_dict['layout']['yaxis']['title']['text'] == 'Actual'
+    assert len(fig_dict['data']) == 2
+    assert fig_dict['data'][0]['name'] == 'y = x line'
+    assert fig_dict['data'][0]['x'] == fig_dict['data'][0]['y']
+    assert len(fig_dict['data'][1]['x']) == len(y_true)
+    assert fig_dict['data'][1]['marker']['color'] == '#0000ff'
+    assert fig_dict['data'][1]['name'] == "Values"
+
+
+def test_graph_prediction_vs_actual():
+    go = pytest.importorskip('plotly.graph_objects', reason='Skipping plotting test because plotly not installed')
+    y_true = [1, 2, 3, 4, 5, 6, 7, 8, 9, 10, 11, 12]
+    y_pred = [5, 4, 3, 8, 6, 3, 5, 9, 7, 12, 1, 2]
+
+    with pytest.raises(ValueError, match="Threshold must be positive!"):
+        graph_prediction_vs_actual(y_true, y_pred, outlier_threshold=-1)
+
+    fig = graph_prediction_vs_actual(y_true, y_pred, outlier_threshold=100)
+    assert isinstance(fig, type(go.Figure()))
+    fig_dict = fig.to_dict()
+    assert fig_dict['layout']['title']['text'] == 'Predicted vs Actual Values Scatter Plot'
+    assert fig_dict['layout']['xaxis']['title']['text'] == 'Prediction'
+    assert fig_dict['layout']['yaxis']['title']['text'] == 'Actual'
+    assert len(fig_dict['data']) == 2
+    assert fig_dict['data'][1]['marker']['color'] == '#0000ff'
+
+    y_true = pd.Series(y_true)
+    y_pred = pd.Series(y_pred)
+    fig = graph_prediction_vs_actual(y_true, y_pred, outlier_threshold=6.1)
+    assert isinstance(fig, type(go.Figure()))
+    fig_dict = fig.to_dict()
+    assert fig_dict['layout']['title']['text'] == 'Predicted vs Actual Values Scatter Plot'
+    assert fig_dict['layout']['xaxis']['title']['text'] == 'Prediction'
+    assert fig_dict['layout']['yaxis']['title']['text'] == 'Actual'
+    assert len(fig_dict['data']) == 3
+    assert fig_dict['data'][1]['marker']['color'] == '#0000ff'
+    assert len(fig_dict['data'][1]['x']) == 10
+    assert len(fig_dict['data'][1]['y']) == 10
+    assert fig_dict['data'][1]['name'] == "< outlier_threshold"
+    assert fig_dict['data'][2]['marker']['color'] == '#ffff00'
+    assert len(fig_dict['data'][2]['x']) == 2
+    assert len(fig_dict['data'][2]['y']) == 2
+    assert fig_dict['data'][2]['name'] == ">= outlier_threshold"
