@@ -4,14 +4,17 @@ from collections import namedtuple
 
 import numpy as np
 import pandas as pd
+import woodwork as ww
 from sklearn.utils import check_random_state
 
-from evalml.exceptions import MissingComponentError
+from evalml.exceptions import (
+    EnsembleMissingPipelinesError,
+    MissingComponentError
+)
 from evalml.utils import get_logger
 
 logger = get_logger(__file__)
 
-
 numeric_dtypes = ['int16', 'int32', 'int64', 'float16', 'float32', 'float64']
 boolean = ['bool']
 numeric_and_boolean_dtypes = numeric_dtypes + boolean
@@ -166,7 +169,8 @@ def _get_subclasses(base_class):
     return subclasses
 
 
-_not_used_in_automl = {'BaselineClassifier', 'BaselineRegressor', 'DecisionTreeClassifier', 'DecisionTreeRegressor',
+_not_used_in_automl = {'BaselineClassifier', 'BaselineRegressor',
+                       'StackedEnsembleClassifier', 'StackedEnsembleRegressor',
                        'ModeBaselineBinaryPipeline', 'BaselineBinaryPipeline', 'MeanBaselineRegressionPipeline',
                        'BaselineRegressionPipeline', 'ModeBaselineMulticlassPipeline', 'BaselineMulticlassPipeline'}
 
@@ -197,7 +201,8 @@ def get_importable_subclasses(base_class, used_in_automl=True):
             classes.append(cls)
         except (ImportError, MissingComponentError, TypeError):
             logger.debug(f'Could not import class {cls.__name__} in get_importable_subclasses')
-
+        except EnsembleMissingPipelinesError:
+            classes.append(cls)
     if used_in_automl:
         classes = [cls for cls in classes if cls.__name__ not in _not_used_in_automl]
 
@@ -205,7 +210,7 @@ def get_importable_subclasses(base_class, used_in_automl=True):
 
 
 def _rename_column_names_to_numeric(X):
-    """Used in XGBoost classifier and regressor classes to rename column names
+    """Used in LightGBM classifier class and XGBoost classifier and regressor classes to rename column names
         when the input is a pd.DataFrame in case it has column names that contain symbols ([, ], <) that XGBoost cannot natively handle.
 
     Arguments:
@@ -214,8 +219,18 @@ def _rename_column_names_to_numeric(X):
     Returns:
         Transformed X where column names are renamed to numerical values
     """
-    name_to_col_num = dict((col, col_num) for col_num, col in enumerate(X.columns.values))
-    return X.rename(columns=name_to_col_num, inplace=False)
+    X_t = X
+    if isinstance(X, np.ndarray):
+        return pd.DataFrame(X)
+    if isinstance(X, ww.DataTable):
+        X_t = X.to_dataframe()
+        logical_types = X.logical_types
+    name_to_col_num = dict((col, col_num) for col_num, col in enumerate(list(X.columns)))
+    X_renamed = X_t.rename(columns=name_to_col_num, inplace=False)
+    if isinstance(X, ww.DataTable):
+        renamed_logical_types = dict((name_to_col_num[col], logical_types[col]) for col in logical_types)
+        return ww.DataTable(X_renamed, logical_types=renamed_logical_types)
+    return X_renamed
 
 
 def jupyter_check():
@@ -228,9 +243,9 @@ def jupyter_check():
         Boolean: True if Ipython, False otherwise
     """
     try:
-        get_ipython()
-        return True
-    except NameError:
+        ipy = import_or_raise("IPython")
+        return ipy.core.getipython.get_ipython()
+    except Exception:
         return False
 
 
@@ -249,3 +264,115 @@ def safe_repr(value):
         if np.isinf(value):
             return f"float('{repr(value)}')"
     return repr(value)
+
+
+def is_all_numeric(df):
+    """Checks if the given DataFrame contains only numeric values
+
+    Arguments:
+        df (DataFrame): The DataFrame to check datatypes of
+
+    Returns:
+        True if all the DataFrame columns are numeric and are not missing any values, False otherwise
+    """
+    if df.isnull().any().any():
+        return False
+    for dtype in df.dtypes:
+        if dtype not in numeric_and_boolean_dtypes:
+            return False
+    return True
+
+
+def _convert_to_woodwork_structure(data):
+    """
+    Takes input data structure, and if it is not a Woodwork data structure already, will convert it to a Woodwork DataTable or DataColumn structure.
+    """
+    ww_data = data
+    if isinstance(data, ww.DataTable) or isinstance(data, ww.DataColumn):
+        return ww_data
+    # Convert numpy data structures to pandas data structures
+    if isinstance(data, list):
+        ww_data = np.array(data)
+
+    if isinstance(ww_data, pd.api.extensions.ExtensionArray) or (isinstance(ww_data, np.ndarray) and len(ww_data.shape) == 1):
+        ww_data = pd.Series(ww_data)
+    elif isinstance(ww_data, np.ndarray):
+        ww_data = pd.DataFrame(ww_data)
+
+    # Convert pandas data structures to Woodwork data structures
+    if isinstance(ww_data, pd.Series):
+        return ww.DataColumn(ww_data)
+    return ww.DataTable(ww_data, copy_dataframe=True)
+
+
+def _convert_woodwork_types_wrapper(pd_data):
+    """
+    Converts a pandas data structure that may have extension or nullable dtypes to dtypes that numpy can understand and handle.
+
+    Arguments:
+        pd_data (pd.Series, pd.DataFrame, pd.ExtensionArray): Pandas data structure
+
+    Returns:
+        Modified pandas data structure (pd.DataFrame or pd.Series) with original data and dtypes that can be handled by numpy
+    """
+    nullable_to_numpy_mapping = {pd.Int64Dtype: 'int64',
+                                 pd.BooleanDtype: 'bool',
+                                 pd.StringDtype: 'object'}
+    nullable_to_numpy_mapping_nan = {pd.Int64Dtype: 'float64',
+                                     pd.BooleanDtype: 'object',
+                                     pd.StringDtype: 'object'}
+
+    if isinstance(pd_data, pd.api.extensions.ExtensionArray):
+        if pd.isna(pd_data).any():
+            return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping_nan[type(pd_data.dtype)])
+        return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping[type(pd_data.dtype)])
+    if (isinstance(pd_data, pd.Series) and type(pd_data.dtype) in nullable_to_numpy_mapping):
+        if pd.isna(pd_data).any():
+            return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping_nan[type(pd_data.dtype)], index=pd_data.index)
+        return pd.Series(pd_data.to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping[type(pd_data.dtype)], index=pd_data.index)
+    if isinstance(pd_data, pd.DataFrame):
+        for col_name, col in pd_data.iteritems():
+            if type(col.dtype) in nullable_to_numpy_mapping:
+                if pd.isna(pd_data[col_name]).any():
+                    pd_data[col_name] = pd.Series(pd_data[col_name].to_numpy(na_value=np.nan), dtype=nullable_to_numpy_mapping_nan[type(pd_data[col_name].dtype)])
+                else:
+                    pd_data[col_name] = pd_data[col_name].astype(nullable_to_numpy_mapping[type(col.dtype)])
+    return pd_data
+
+
+def pad_with_nans(pd_data, num_to_pad):
+    """Pad the beginning num_to_pad rows with nans.
+
+    Arguments:
+        pd_data (pd.DataFrame or pd.Series): Data to pad.
+
+    Returns:
+        pd.DataFrame or pd.Series
+    """
+    if isinstance(pd_data, pd.Series):
+        padding = pd.Series([None] * num_to_pad)
+    else:
+        padding = pd.DataFrame({col: [None] * num_to_pad
+                                for col in pd_data.columns})
+    return pd.concat([padding, pd_data], ignore_index=True).infer_objects()
+
+
+def drop_rows_with_nans(pd_data_1, pd_data_2):
+    """Drop rows that have any NaNs in both pd_data_1 and pd_data_2.
+
+    Arguments:
+        pd_data_1 (pd.DataFrame or pd.Series): Data to subset.
+        pd_data_2 (pd.DataFrame or pd.Series): Data to subset.
+
+    Returns:
+        tuple of pd.DataFrame or pd.Series
+    """
+
+    def _not_nan(pd_data):
+        if isinstance(pd_data, pd.Series):
+            return ~pd_data.isna().values
+        else:
+            return ~pd_data.isna().any(axis=1).values
+
+    mask = np.logical_and(_not_nan(pd_data_1), _not_nan(pd_data_2))
+    return pd_data_1.iloc[mask], pd_data_2.iloc[mask]
